import {
  View,
  Text,
  StyleSheet,
  Image,
  Dimensions,
  Platform,
  ScrollView,
} from "react-native";
import React, { useEffect, useState } from "react";
import { translate } from "react-native-digitcamera/src/common/localize/i18n";
import Carousel from "react-native-snap-carousel";
import Orientation from "react-native-orientation";
import { PrimaryButton } from "react-native-digitcamera/src/common/ThemedComponents";
import Header from "./Header";
import Database from "../../../../Components/common/DAsyncStorage";
import style from "../../../../Components/common/CommonStyle";
import { useSelector } from "react-redux";
const iOS = Platform.OS === "ios";

/* for sdk version 21*/
// const IS_SDK_21 = false;
const IS_SDK_21 = !iOS && Platform.Version === 21;
console.log("^^^ ANDROID SDK VERSION ^^^", IS_SDK_21);

/* Get max dimension for screen width */
const getMaxWidth = () => {
  return Math.round(
    Math.max(Dimensions.get("screen").height, Dimensions.get("screen").width)
  );
};

/*Initial SCREEN_WIDTH*/
let SCREEN_WIDTH = getMaxWidth();

/*Stretch local images*/
/*contain remote images
set this variable to true 
*/
let IS_LOCAL = false;

var instructionInDb = Database.get("PIVechicleInstruction");

// let instructionStringFront, instructionStringBack;
var titleArr = [];

const RCBPreviewScreen = ({ navigation, route }) => {
  const { proceedCallback } = route.params;
  const [instructionArr, setInstructionArr] = useState(
    JSON.parse(instructionInDb?.instuction)
  );
  const [RCBData, setRCBData] = useState([]);

  //Get RCB1 & RCB2 uri from redux
  const RCBUris = useSelector((state) => state.rcbPreviewData.rcbPreviewData);
  if (RCBUris.length !== 0) {
    IS_LOCAL = true;
  }

  console.log("^^^ RCBUris Data ^^^^", RCBUris);

  useEffect(() => {
    /* for sdk version 21, landscape mode is not working
      setting it to portrait mode.
    */
    if (IS_SDK_21) {
      Orientation.lockToPortrait();
    }

    if (!iOS) {
      const Immersive = require("react-native-immersive").Immersive;
      Immersive.setImmersive(false);
    }

    console.log("^^^^ IS_LOCAL ^^^^", IS_LOCAL);

    getRCBInstructions();

    let item = instructionArr.filter((item) => item.imageName.includes("RCB"));
    let newRCBData = [];
    if (item !== undefined && item.length !== 0) {
      /* once received remote assets we set IS_LOCAL to false*/
      IS_LOCAL = false;
      item.forEach((item) => {
        let RCBItem = {
          name: item.imageName,
          image: item.stepAssests,
          info: `RC ${item.imageName === "RCB1" ? "FRONT" : "BACK"} SAMPLE`,
        };
        newRCBData.push(RCBItem);
      });
    }
    setRCBData([...newRCBData]);
    /* Incase if there is orientation change */
    SCREEN_WIDTH = getMaxWidth();
    // for re-render immersive
    let unsubscribe = navigation.addListener("focus", () => {
      if (!iOS) {
        const Immersive = require("react-native-immersive").Immersive;
        Immersive.setImmersive(false);
      }
    });
    return () => {
      unsubscribe();
    };
  }, []);

  const rcBookData = [
    {
      name: "RCB1",
      image: "https://cdn.godigit.com/digitEdgeAssets/Motor/4W_PI_RCB1_V2.jpg",
      info: "RC FRONT SAMPLE",
    },
    {
      name: "RCB2",
      image: "https://cdn.godigit.com/digitEdgeAssets/Motor/4W_PI_RCB2_V2.jpg",
      info: "RC BACK SAMPLE",
    },
  ];

  const getRCBInstructions = () => {
    titleArr = [];
    const item = instructionArr.filter((item) =>
      item.imageName.includes("RCB")
    );
    if (item !== undefined) {
      item.map((itmObj) => {
        const subTitleArr = itmObj?.TSurveyInstructions;
        if (subTitleArr !== undefined) {
          subTitleArr.map((subItemObj) => {
            const subTtl = subItemObj?.instructionData;
            if (subTtl !== undefined) {
              titleArr.push(subTtl);
            }
          });
        }
      });
    }
  };

  const _renderRcBookData = ({ item, index }) => {
    return (
      // Image View
      <View style={styles.imageView}>
        {item.image == undefined ? null : (
          <Image
            source={{ uri: item.image }}
            style={[
              styles.imageItem,
              { resizeMode: IS_LOCAL ? "stretch" : "contain" },
            ]}
          />
        )}
        <View style={styles.borderOverlay}></View>
        <View style={styles.borderOverlay1}></View>
        <Text style={styles.sampleText}>{translate(item.info)}</Text>
      </View>
    );
  };

  const handleProceed = () => {
    if (RCBUris.length !== 0) {
      navigation.navigate("Toturial", { fromRCB: true });
    } else if (RCBUris.length == 0) {
      if (proceedCallback !== undefined) {
        proceedCallback();
      }
    }
  };

  return (
    <View style={styles.rcbContainer}>
      <Header
        showTitle={"Instruction"}
        onbackPress={() => {
          navigation.goBack();
        }}
      />
      <View style={styles.mainViewWrapper}>
        <View style={styles.mainView}>
          {/* crausel Image View */}
          <View style={styles.carouselView}>
            <Carousel
              data={RCBUris.length === 0 ? rcBookData : RCBUris}
              renderItem={_renderRcBookData}
              sliderWidth={SCREEN_WIDTH / 2}
              itemWidth={SCREEN_WIDTH / 2}
              autoplay={true}
              loop={true}
            />
          </View>
          <View style={styles.detailsView}>
            <View style={styles.details}>
              <Text style={[style.muliBoldDB, styles.title]}>
                RC Book Images
              </Text>
              <ScrollView style={{ flex: 0.4, height: "100%" }}>
                {titleArr !== undefined &&
                  titleArr.length > 0 &&
                  titleArr.map((titles) => {
                    return (
                      <Text style={[style.muliRegLGWOB, styles.subtitle]}>
                        {titles}
                      </Text>
                    );
                  })}
              </ScrollView>
            </View>
            <View style={{ flex: 0.3 }}>
              <PrimaryButton onPress={handleProceed}>Proceed</PrimaryButton>
            </View>
          </View>
        </View>
      </View>
    </View>
  );
};

const styles = StyleSheet.create({
  rcbContainer: {
    flex: IS_SDK_21 ? 1 : 0,
    backgroundColor: "white",
    paddingHorizontal: IS_SDK_21 ? 0 : 10,
  },
  mainViewWrapper: {
    flex: IS_SDK_21 ? 1 : 0,
    paddingVertical: IS_SDK_21 ? 0 : 16,
  },
  mainView: {
    flex: IS_SDK_21 ? 1 : 0,
    flexDirection: IS_SDK_21 ? "column" : "row",
    justifyContent: "space-between",
  },
  carouselView: {
    flex: IS_SDK_21 ? 0.5 : 0.55,
  },
  imageView: {
    marginHorizontal: IS_SDK_21 ? 0 : "2%",
    flexDirection: "column",
  },
  imageItem: {
    width: IS_SDK_21 ? "90%" : "100%",
    height: "90%",
    padding: IS_SDK_21 ? 0 : 10,
    alignItems: "center",
  },
  borderOverlay: {
    position: "absolute",
    justifyContent: "center",
    borderWidth: 10,
    borderRadius: 20,
    borderColor: "white",
    width: IS_SDK_21 ? "90%" : "100%",
    backgroundColor: "transparent",
    height: "95%",
    flexDirection: "column",
  },
  borderOverlay1: {
    position: "absolute",
    justifyContent: "center",
    borderWidth: 10,
    borderColor: "white",
    width: IS_SDK_21 ? "90%" : "100%",
    backgroundColor: "transparent",
    height: "95%",
    flexDirection: "column",
  },
  sampleText: {
    fontFamily: "Muli-SemiBold",
    fontSize: 12,
    color: "#999999",
    alignItems: "center",
    paddingLeft: 20,
    marginTop: 3,
  },
  rcTitle: {
    fontFamily: "Muli-Black",
    fontSize: 20,
    marginBottom: 17,
  },
  rcTypeText: {
    fontFamily: "Muli-Bold",
    fontSize: 14,
  },
  detailsView: {
    paddingHorizontal: IS_SDK_21 ? 16 : 0,
    flex: IS_SDK_21 ? 0.6 : 0.4,
    justifyContent: "space-between",
  },
  details: {
    flex: 0.7,
    justifyContent: "space-between",
    flexDirection: "column",
  },
  title: {
    fontSize: 24,
    marginBottom: 16,
  },
  subtitle: {
    fontSize: 18,
    marginBottom: 16,
  },
  subtitle1: {
    fontSize: 18,
  },
});

export default RCBPreviewScreen;
