import { SELFSURVEYSERVICE_DOCUMENT_URL } from "react-native-digitcamera/src/Api/ApiUrls";
import { UELogEvent } from "react-native-digitcamera/src/common/libEventLog/UserExperior/LibUserExperior";
import Database from "../../../../Components/common/DAsyncStorage";
import DeviceInfo from "react-native-device-info";
import { forwardRef, useEffect, useState } from "react";
import { Alert, Platform } from "react-native";

const { getImei } = require("react-native-imei");
const iOS = Platform.OS === "ios";

export async function UploadFile(
  mediaUri,
  DocumentImageName,
  ext,
  failedCallBack
) {
  var MAC = "";
  var deviceName = "";
  var IP = "";
  var apiLevel = "";
  var IMEI = "";
  try {
    var file = "file://";
    const uri = iOS ? mediaUri.replace("file://", "") : file + mediaUri;
    console.log("*** UploadFile : " + DocumentImageName + " uri: " + uri);
    var PILocation = Database.get("PILocation");
    var currentLatitude = PILocation?.lat;
    var currentLongitude = PILocation?.long;
    var PIVechicleData = Database.get("PIVechicleData");
    var activityId = PIVechicleData?.activityId;
    var quoteNumber = PIVechicleData?.quoteNumber;
    var regNumber = PIVechicleData?.licensePlateNumber;
    var PIOdometerData = Database.get("PIOdometerData");
    console.log(
      "**** UploadFile PIOdometerData: " + JSON.stringify(PIOdometerData)
    );
    deviceName = await DeviceInfo.getDeviceName();
    console.log("*** UploadFile getDeviceName: " + deviceName);
    if (activityId == undefined || activityId.length == 0) {
      Alert.alert("Oops!", "Something went wrong, please retry again");
      if (failedCallBack !== undefined) {
        failedCallBack();
      }
    }

    MAC = await DeviceInfo.getMacAddress();
    console.log("*** UploadFile getMacAddress: " + MAC);
    IP = await DeviceInfo.getIpAddress();
    console.log("*** UploadFile getIpAddress: " + IP);

    apiLevel = await DeviceInfo.getApiLevel();
    console.log("*** UploadFile getApiLevel: " + apiLevel);
    if (!iOS) {
      if (apiLevel > 28) {
        IMEI = await DeviceInfo.getAndroidId();
      } else {
        const imeiList = await getImei();
        if (imeiList !== undefined) {
          IMEI = imeiList[0];
        }
      }
    }
    console.log("*** UploadFile getImei / getAndroidId: " + IMEI);

    UELogEvent("uploadImage is started", {
      uri: JSON.stringify(uri),
      documentName: JSON.stringify(DocumentImageName),
      ImageName: JSON.stringify(activityId + "_" + DocumentImageName + ext),
    });
    console.log("In Upload Uploading Image Name ", DocumentImageName);
    console.log("IMAGE NAME  ", activityId + "_" + DocumentImageName + ext);
    const xhr = new XMLHttpRequest();
    const formData = new FormData();
    console.log("IMAGE URI TO BE UPLOADED > > >   ", uri);

    const initStatusRealm = () => {
      Database.set("PIMediaStatus", {
        status: "uploading", // uploading, uploaded, failed
        uri: uri,
        imageName: DocumentImageName,
        activityId: activityId,
        quoteNumber: quoteNumber,
        regNumber: regNumber,
      });
    };

    initStatusRealm();

    const handleProgress = async (event) => {
      await Database.remove("PIVideoCompleteStatus");
      Database.set("PIVideoCompleteStatus", {
        completePercentage: Math.round(event.loaded * 100) / event.total,
      });
      UELogEvent("handleProgress started", {
        "File Uploaded": JSON.stringify(
          Math.round(event.loaded * 100) / event.total
        ),
      });
      console.log(
        "File Uploaded => ",
        Math.round(event.loaded * 100) / event.total
      );
    };
    const documentUploadData = {
      activityId: activityId,
      data: null,
      dataUploadStatus: 0,
      fullName: activityId + "_" + DocumentImageName,
      geoLocation: {
        isBlocked: "",
        deviceName: deviceName,
        latitude: currentLatitude,
        longitude: currentLongitude,
        operatingSystem: DeviceInfo.getSystemVersion(),
        timezone: "Asia/Kolkata",
        deviceTime: null,
        ipAddress: IP,
        deviceIMEI: IMEI,
        macAddress: MAC,
        documentSource: "DigitEdge",
      },
      isLast: "false",
      isLastData: "false",
      isLastDocument: "false",
      isSurveyor: "false",
      manualOdometerReading:
        DocumentImageName == "DBD" ? PIOdometerData?.readings : "",
      source: "DIGITEDGE",
    };

    formData.append("file", {
      uri: uri,
      type: "image/jpeg",
      fileName: activityId + "_" + DocumentImageName,
      name: activityId + "_" + DocumentImageName + ext,
    });
    formData.append("documentData", JSON.stringify(documentUploadData));

    UELogEvent("started xhr events in uploadImage", {
      formdata: JSON.stringify(formData),
    });

    xhr.upload.addEventListener("progress", handleProgress);
    xhr.addEventListener("load", (load) => {
      updateStatusRealm(activityId, DocumentImageName, "uploaded");
    });

    xhr.addEventListener("abort", () => {
      updateStatusRealm(activityId, DocumentImageName, "failed");
    });
    xhr.addEventListener("error", (error) => {
      updateStatusRealm(activityId, DocumentImageName, "failed");

      console.log("*** startUpolading error: " + JSON.stringify(error));
    });
    xhr.addEventListener("timeout", () => {
      updateStatusRealm(activityId, DocumentImageName, "failed");
    });
    xhr.open("POST", SELFSURVEYSERVICE_DOCUMENT_URL);
    xhr.setRequestHeader(
      "Accept",
      "*/*",
      "Content-Type",
      "multipart/form-data"
    );
    xhr.send(formData);
  } catch (error) {
    console.log("*** UploadFile catch: " + error);
    updateStatusRealm(activityId, DocumentImageName, "failed");
  }

  const updateStatusRealm = (activityId, DocumentImageName, newStatus) => {
    Database.get("PIMediaStatus")?.map((mediaObj) => {
      console.log("**** updateStatusRealm before: " + JSON.stringify(mediaObj));
      if (
        mediaObj.activityId == activityId &&
        mediaObj.imageName === DocumentImageName
      ) {
        mediaObj.status = newStatus;
        console.log(
          "**** updateStatusRealm after: " + JSON.stringify(mediaObj)
        );
      }
    });
  };
}

export default UploadFile;
