import React, { useEffect, useState } from "react";
import { StyleSheet, View, Image, Text, BackHandler } from "react-native";
import { translate } from "react-native-digitcamera/src/common/localize/i18n";
import { ProgressBar } from "react-native-paper";
import reactotron from "reactotron-react-native";
import Header from "./Header";
import Orientation from "../../../react-native-orientation";
import { useSelector } from "react-redux";
import {
  UELogEvent,
  UELogMessage,
} from "../common/libEventLog/UserExperior/LibUserExperior";
import Database from "../../../../Components/common/DAsyncStorage";
import { PrimaryButton } from "../../../../Components/common/ThemedComponents";

var PIVechicleData = Database.get("PIVechicleData");
var uploadedImageCount = 0;
var uploadedImages = [];
var totalImages = 0;
var uploadedInterval;
const VideoPIProgress = ({ navigation, route }) => {
  const [, updateState] = React.useState();
  const forceUpdate = React.useCallback(() => updateState({}), []);
  const [docProgress, setDocProgress] = useState(0);
  var activityId = PIVechicleData?.activityId;
  useEffect(() => {
    Orientation.lockToPortrait();
    uploadedInterval = setInterval(() => {
      const completedCount = Database.get(
        "PIVideoCompleteStatus"
      )?.completePercentage;
      setDocProgress(completedCount);
      console.log("**** uploadedInterval progress: " + completedCount);
      const mediaStatusObjs = Database.get("PIMediaStatus");
      console.log(
        "**** Progress mediaStatusObjs: " + JSON.stringify(mediaStatusObjs)
      );
      totalImages = mediaStatusObjs.length;
      console.log("**** Progress totalImages: " + totalImages);

      uploadedImages = [];
      mediaStatusObjs.filter((item) => {
        if (item?.status === "uploaded") {
          uploadedImages.push(item);
        }
      });
      console.log("**** Progress uploadedImages: " + uploadedImages.length);

      uploadedImageCount = uploadedImages.length;
    }, 1000);

    let unsubscribe = navigation.addListener("focus", () => {
      Orientation.lockToPortrait();
    });

    const backHandler = BackHandler.addEventListener(
      "hardwareBackPress",
      () => {
        return true;
      }
    );

    return () => {
      backHandler.remove();
      unsubscribe();
    };
  }, []);

  const navigateTOthankYou = () => {
    const interval = setInterval(() => {
      if (uploadedImageCount >= totalImages) {
        if (docProgress >= 100) {
          clearInterval(interval);
          clearInterval(uploadedInterval);
          navigation.navigate("ThankYou", { activityId: activityId });
        }
      }
    }, 1000);
  };

  return (
    <View style={styles.main}>
      <Header
        hideArrowBackButton={true}
        onlanguagechange={() => {
          forceUpdate();
        }}
        onbackPress={() => {
          navigation.goBack();
        }}
      />
      {/* GIF view */}
      <View style={styles.gifView}>
        <Image
          source={{
            uri: "https://d2h44aw7l5xdvz.cloudfront.net/assets/gif/cycle.gif",
          }}
          style={{
            width: "50%",
            height: "50%",
            alignSelf: "center",
            resizeMode: "center",
          }}
        />
      </View>
      {/* Progress View */}
      <View style={styles.progressView}>
        <Text style={styles.boldText}>{"Uploading in progress"}</Text>
        <ProgressBar
          progress={docProgress * 0.01}
          color={"#FFBB00"}
          style={{ height: 12, borderRadius: 6, backgroundColor: "#F5F5F5" }}
        />
        <Text style={styles.doneText}>{docProgress + "% Done"}</Text>
        <Text style={styles.subText}>
          {
            "Once the upload is done, we will let you know. You can continue using your phone till then."
          }
        </Text>
        {navigateTOthankYou()}
      </View>
      <View style={styles.buttonView}>
        {/* <PrimaryButton
          onPress={() => {
            console.log("on Goto Homescreen >>> ");
          }}
          style={{ margin: 24 }}
        >
          {"Go to Homescreen"}
        </PrimaryButton> */}
      </View>
    </View>
  );
};
const styles = StyleSheet.create({
  main: {
    flex: 1,
    backgroundColor: "#FFFFFF",
  },
  gifView: {
    flex: 0.5,
    justifyContent: "center",
    marginBottom: 40,
    marginLeft: 24,
    marginRight: 24,
    alignItems: "center",
  },
  progressView: {
    flex: 0.4,
    marginLeft: 24,
    marginRight: 24,
  },
  processingText: {
    fontFamily: "Muli-Bold",
    fontSize: 20,
    alignSelf: "center",
    marginBottom: 15,
  },
  boldText: {
    fontFamily: "Muli-Regular",
    fontSize: 20,
    alignSelf: "center",
    marginBottom: 24,
  },
  doneText: {
    fontFamily: "Muli-Regular",
    fontSize: 14,
    marginTop: 12,
    alignSelf: "center",
  },
  subText: {
    fontFamily: "Muli-ExtraBold",
    fontSize: 14,
    marginTop: 16,
    alignSelf: "center",
  },
  buttonView: {
    flex: 0.1,
    justifyContent: "center",
  },
});
export default VideoPIProgress;
